from setuptools import setup

setup(name='valak_distributions',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['valak_distributions'],
      zip_safe=False)
